<?php
/**
 * Blog Settings
 *
 * Register Blog Settings section, settings and controls for Theme Customizer
 *
 * @package Salal
 */

/**
 * Adds blog settings in the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_blog_settings( $wp_customize ) {

	// Add Sections for Post Settings.
	$wp_customize->add_section( 'salal_section_blog', array(
		'title'    => esc_html__( 'Blog Settings', 'salal' ),
		'priority' => 30,
		'panel' => 'salal_options_panel',
	) );

	// Add Settings and Controls for blog layout.
	$wp_customize->add_setting( 'salal_theme_options[blog_layout]', array(
		'default'           => 'large',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_select',
	) );

	$wp_customize->add_control( 'salal_theme_options[blog_layout]', array(
		'label'    => esc_html__( 'Blog Layout', 'salal' ),
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[blog_layout]',
		'type'     => 'select',
		'choices'  => array(
			'large' => esc_html__( 'Large Posts', 'salal' ),
			'list'  => esc_html__( 'Post List', 'salal' ),
			'grid'  => esc_html__( 'Post Grid', 'salal' ),
		),
	) );

	// Add Settings and Controls for Layout.
	$wp_customize->add_setting( 'salal_theme_options[sidebar_position]', array(
		'default'           => 'right',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_select',
	) );

	$wp_customize->add_control( 'salal_theme_options[sidebar_position]', array(
		'label'    => esc_html__( 'Sidebar Position', 'salal' ),
		'description' => esc_html__( 'This will let you choose your sidebar position for the blog or pages.', 'salal' ), 
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[sidebar_position]',
		'type'     => 'radio',
		'choices'  => array(
			'left'  => esc_html__( 'Left Sidebar', 'salal' ),
			'right' => esc_html__( 'Right Sidebar', 'salal' ),
			'none' => esc_html__( 'No Sidebar', 'salal' ),
		),
	) );
	
	// Add Settings and Controls for blog content.
	$wp_customize->add_setting( 'salal_theme_options[blog_content]', array(
		'default'           => 'excerpt',
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_select',
	) );

	$wp_customize->add_control( 'salal_theme_options[blog_content]', array(
		'label'    => esc_html__( 'Blog Content', 'salal' ),
		'description' => esc_html__( 'This will let you choose to use excerpts for your blog summaries.', 'salal' ), 
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[blog_content]',
		'type'     => 'radio',
		'choices'  => array(
			'index'   => esc_html__( 'Full post', 'salal' ),
			'excerpt' => esc_html__( 'Post excerpt', 'salal' ),
		),
	) );

	// Add Setting and Control for Excerpt Length.
	$wp_customize->add_setting( 'salal_theme_options[excerpt_length]', array(
		'default'           => 35,
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'salal_theme_options[excerpt_length]', array(
		'label'    => esc_html__( 'Excerpt Length', 'salal' ),
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[excerpt_length]',
		'type'     => 'number',
        'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 1,
        ),		
	) );

	// Add Partial for Blog Layout and Excerpt Length.
	$wp_customize->selective_refresh->add_partial( 'salal_blog_content_partial', array(
		'selector'         => '.site-main .post-wrapper',
		'settings'         => array(
			'salal_theme_options[blog_layout]',
			'salal_theme_options[blog_content]',
			'salal_theme_options[excerpt_length]',
		),
		'render_callback'  => 'salal_customize_partial_blog_content',
		'fallback_refresh' => false,
	) );

	// Add Setting and Control for Read More Text.
	$wp_customize->add_setting( 'salal_theme_options[read_more_text]', array(
		'default'           => esc_html__( 'Continue Reading', 'salal' ),
		'type'              => 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'salal_theme_options[read_more_text]', array(
		'label'    => esc_html__( 'Read More Text', 'salal' ),
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[read_more_text]',
		'type'     => 'text',
	) );
	
	
	// Add Post Layout Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[archive_heading_option]', array(
			'label' => esc_html__( 'Archive Headings', 'salal' ),
			'section' => 'salal_section_blog',
			'settings' => array(),
		)
	) );	
	
	// Add Setting and Control for showing archive title group.
	$wp_customize->add_setting( 'salal_theme_options[archive_title_group]', array(
		'default'           => true,
		'type'           	=> 'option',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_theme_options[archive_title_group]', array(
		'label'    => esc_html__( 'Display the Archive Title and Description', 'salal' ),
		'section'  => 'salal_section_blog',
		'settings' => 'salal_theme_options[archive_title_group]',
		'type'     => 'checkbox',
	) );	
	
	
	
	
}
add_action( 'customize_register', 'salal_customize_register_blog_settings' );

/**
 * Render the blog title for the selective refresh partial.
 */
function salal_customize_partial_blog_title() {
	echo wp_kses_post( salal_get_option( 'blog_title' ) );
}

/**
 * Render the blog description for the selective refresh partial.
 */
function salal_customize_partial_blog_description() {
	echo wp_kses_post( salal_get_option( 'blog_description' ) );
}

/**
 * Render the blog content for the selective refresh partial.
 */
function salal_customize_partial_blog_content() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/posts/content', esc_attr( salal_get_option( 'blog_content' ) ) );
	}
}
