<?php
/**
 * Typography Settings
 *
 * Register Typography section, settings and controls for Theme Customizer
 *
 * @package Salal
 */

/**
 * Adds all typography settings to the Customizer
 *
 * @param object $wp_customize / Customizer Object.
 */
function salal_customize_register_typography_settings( $wp_customize ) {

	// Add Section for Theme Options.
	$wp_customize->add_section( 'salal_section_typography', array(
		'title'    => esc_html__( 'Typography Settings', 'salal' ),
		'priority' => 52,
		'panel'    => 'salal_options_panel',
	) );

	// Add Google Fonts Headline.
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[google_fonts_option]', array(
			'label' => esc_html__( 'Default Google Fonts', 'salal' ),
			'section' => 'salal_section_typography',
			'settings' => array(),
		)
	) );

	// Enable Default Google Fonts
	$wp_customize->add_setting( 'salal_default_google_fonts', array(
		'default'           => true,
		'description' => esc_html__( 'This theme has a couple Google Fonts included. If you choose to use a plugin for different fonts, you can disable them.', 'salal' ),
		'sanitize_callback' => 'salal_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'salal_default_google_fonts', array(
		'label'    => esc_html__( 'Enable the Default Google Fonts', 'salal' ),
		'section'  => 'salal_section_typography',
		'type'     => 'checkbox',
	) );	
	
	// Dropcap
	$wp_customize->add_control( new Salal_Customize_Header_Control(
		$wp_customize, 'salal_theme_options[dropcap_options]', array(
			'label' => esc_html__( 'Dropcap Options', 'salal' ),
			'section' => 'salal_section_typography',
			'settings' => array(),
		)
	) );	


// Dropcap Colour
 	$wp_customize->add_setting( 'salal_dropcap_colour', array(
		'default'        => '#c39f76',
		'sanitize_callback' => 'sanitize_hex_color',
	) );	
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'salal_dropcap_colour', array(
		'label'   => esc_html__( 'Dropcap Colour', 'salal' ),
		'section' => 'salal_section_typography',
		'settings'   => 'salal_dropcap_colour',
	) ) );	
		
}
add_action( 'customize_register', 'salal_customize_register_typography_settings' );
